@@ -1,4 +1,4 @@
-lamNames <- function(l) {
+lam_names <- function(l) {
   if (length(l) > 1) {
     d <- ceiling(-log10(-max(diff(l))))
     d <- min(max(d,4), 10)
